// Example of usage of the exception generating class
// Database (in namespace Postgres).
//
// tom.vijlbrief@knoware.nl
//
// Wed Apr 19 18:34:09 CEST 2000

#include <libpq++/PostgresDatabase.h>

#include <typeinfo>
#include <iostream>


using namespace Postgres;

int main()
{
  try {

    Database data("");

    try {
      data.Exec("drop table foo");
    } catch (std::exception &e) {
      cerr << "Drop failed: " << e.what() << endl;
    }

#if 1
    // Allow null values:
    data.Exec("create table foo (a int4, b char(16), d float8)");
#else
    // The following create will result in an exception when
    // attempting to insert NULL later in the program
    data.Exec("create table foo (a int4, b char(16) not null, d float8)");
#endif

    for (int i= 0; i < 2; i++) {
      data.Exec("copy foo from stdin");
      data.PutLine("3\tHello World\t4.5\n");
      data.PutLine("4\tGoodbye World\t7.11\n");
      data.PutLine("\\.\n");
      data.EndCopy();
    }


    for (int loop= 0; loop < 10; ++loop) {

      cout << loop << endl;

      char q[1000];
      sprintf(q, "insert into foo (a) values (%d)", loop);
      cerr << q << endl;
      data.Exec(q);

      data.Exec("select * from foo");
#if 0
      for (int i= 0; i < data.Tuples(); ++i) {
        for (int j= 0; j < data.Fields(); ++j)
 	  cout << data.GetValue(i,j) << ":";
        cout << endl;
      }
#else
      data.DisplayTuples();
#endif

      if (loop == 5) {
        // Start an transaction on Database data
        Database::TransAction t1(data);

        data.Exec("update foo set d = 9.9 where a > 3");
        data.Exec("delete from foo where a < 3");

	// transaction ends here because t1 is destroyed
      }

    }

    {
      Database::Cursor c(data, "select * from foo");
      c.Fetch();
      data.DisplayTuples();
    }

    {
      Database::Cursor c(data, "select * from foo");
      c.Fetch(5);
      for (int i= 0; i < data.Tuples(); ++i) {
        for (int j= 0; j < data.Fields(); ++j)
 	  cout << data.GetValue(i,j) << ":";
        cout << endl;
      }
    }

  } catch (std::exception &e) {
    cerr << typeid(e).name() << ": " << e.what() << endl;
  } catch (...) {
    cerr << "Unknown exception!\n";
  }

  return 0;
}
